@@ -13,7 +13,7 @@ mod kqueue;
 pub use self::kqueue::{Events, Selector};
 
 pub fn from_nix_error(err: ::nix::Error) -> ::std::io::Error {
-    ::std::io::Error::from_raw_os_error(err.errno() as i32)
+    ::std::io::Error::from_raw_os_error(::nix::errno::errno() as i32)
 }
 
 pub use super::FromRawArc;
\ No newline at end of file
